﻿using GalaSoft.MvvmLight;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using GalaSoft.MvvmLight.Command;

namespace SLmvvm01.ViewModel
{
    /// <summary>
    /// This class contains properties that the main View can data bind to.
    /// <para>
    /// Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
    /// </para>
    /// <para>
    /// You can also use Blend to data bind with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm/getstarted
    /// </para>
    /// </summary>
    public class MainViewModel : ViewModelBase
    {
        public string Title
        {
            get
            {
                return "ICommand sample (c) OD";
            }
        }

        private bool isSquareEmpty = true;
        public bool IsSquareEmpty
        {
            get { return isSquareEmpty; }
            set
            {
                isSquareEmpty = value;
                RaisePropertyChanged("IsSquareEmpty");
            }
        }



        public SolidColorBrush SquareFillColor
        {
            get { return isSquareEmpty ? null : new SolidColorBrush(Colors.Black); }
        }

        public RelayCommand EmptySquareCommand { get; set; }
        public string EmptySquareCommandText { get { return "Empty Square"; } }
        public RelayCommand FillSquareCommand { get; set; }
        public string FillSquareCommandText { get { return "Fill Square"; } }



        /// <summary>
        /// Initializes a new instance of the MainViewModel class.
        /// </summary>
        public MainViewModel()
        {
            if (IsInDesignMode)
            {
                // Code runs in Blend --> create design time data.
            }
            else
            {
                // Code runs "for real"
            }
            EmptySquareCommand = new RelayCommand((Action)(() => IsSquareEmpty = true),
                () => !isSquareEmpty);
            FillSquareCommand = new RelayCommand((Action)(() => IsSquareEmpty = false),
                () => isSquareEmpty);
            PropertyChanged += MainViewModel_PropertyChanged;
        }

        void MainViewModel_PropertyChanged(object sender, System.ComponentModel.PropertyChangedEventArgs e)
        {
            if (e.PropertyName == "IsSquareEmpty")
            {
                RaisePropertyChanged("SquareFillColor");
                EmptySquareCommand.RaiseCanExecuteChanged();
                FillSquareCommand.RaiseCanExecuteChanged();
            }
        }


    }
}